@@ -5,7 +5,7 @@ var Range_8h =
     [ "Range< 2, T >", "classnanovdb_1_1util_1_1Range_3_012_00_01T_01_4.html", "classnanovdb_1_1util_1_1Range_3_012_00_01T_01_4" ],
     [ "Range< 3, T >", "classnanovdb_1_1util_1_1Range_3_013_00_01T_01_4.html", "classnanovdb_1_1util_1_1Range_3_013_00_01T_01_4" ],
     [ "Range< int, typename >", "classnanovdb_1_1Range.html", null ],
-    [ "Range1D", "namespacenanovdb_1_1util.html#af3673a774597551e15a27cdf4ac7e71d", null ],
-    [ "Range2D", "namespacenanovdb_1_1util.html#abf41916a456c149b99f70070d372b9d2", null ],
-    [ "Range3D", "namespacenanovdb_1_1util.html#a6065157b6cb3382d22e4fd2fc70eb0c0", null ]
+    [ "nanovdb::util::Range1D", "namespacenanovdb_1_1util.html#af3673a774597551e15a27cdf4ac7e71d", null ],
+    [ "nanovdb::util::Range2D", "namespacenanovdb_1_1util.html#abf41916a456c149b99f70070d372b9d2", null ],
+    [ "nanovdb::util::Range3D", "namespacenanovdb_1_1util.html#a6065157b6cb3382d22e4fd2fc70eb0c0", null ]
 ];
\ No newline at end of file
