@@ -1,5 +1,55 @@
 var NAVTREEINDEX52 =
 {
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler.html#a16eef124fcd2054f4acf5454c9fdb40b":[14,0,6,0,8,67,5],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler.html#a16eef124fcd2054f4acf5454c9fdb40b":[15,0,4,0,6,63,5],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler.html#a3cd26b405c770e2afc491e414fa8c69e":[14,0,6,0,8,67,4],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler.html#a3cd26b405c770e2afc491e414fa8c69e":[15,0,4,0,6,63,4],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler.html#a4612d9059153f35d60fd2fd5f5ab920a":[14,0,6,0,8,67,7],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler.html#a4612d9059153f35d60fd2fd5f5ab920a":[15,0,4,0,6,63,7],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler.html#a48ede07cd0a1182fef5c8ff578a2d1ed":[14,0,6,0,8,67,1],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler.html#a48ede07cd0a1182fef5c8ff578a2d1ed":[15,0,4,0,6,63,1],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler.html#a61a9dd849e7ddc208d2baee20c91576f":[14,0,6,0,8,67,9],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler.html#a61a9dd849e7ddc208d2baee20c91576f":[15,0,4,0,6,63,9],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler.html#a71aa047334cded4135a83e44cda223fb":[14,0,6,0,8,67,6],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler.html#a71aa047334cded4135a83e44cda223fb":[15,0,4,0,6,63,6],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler.html#a72bac11fbbcf9d24c41640d0df8c4010":[14,0,6,0,8,67,12],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler.html#a72bac11fbbcf9d24c41640d0df8c4010":[15,0,4,0,6,63,12],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler.html#aafc1edc93c4d4ba716deb7bb5c7fa6c3":[14,0,6,0,8,67,0],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler.html#aafc1edc93c4d4ba716deb7bb5c7fa6c3":[15,0,4,0,6,63,0],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler.html#ab24b178d6f8fa6440aee947fa4d86ff0":[14,0,6,0,8,67,2],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler.html#ab24b178d6f8fa6440aee947fa4d86ff0":[15,0,4,0,6,63,2],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler.html#abe4365568f76f8f85a0eaff8f84f9f06":[14,0,6,0,8,67,11],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler.html#abe4365568f76f8f85a0eaff8f84f9f06":[15,0,4,0,6,63,11],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler.html#ace14137a24a932554c792b092bc49f21":[14,0,6,0,8,67,10],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler.html#ace14137a24a932554c792b092bc49f21":[15,0,4,0,6,63,10],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler.html#af7f7cd30525c7cbc594ec0fd2859f5eb":[14,0,6,0,8,67,8],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler.html#af7f7cd30525c7cbc594ec0fd2859f5eb":[15,0,4,0,6,63,8],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html":[14,0,6,0,8,68],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html":[15,0,4,0,6,64],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html#a0a813e5afe52be89025bd787ceb32f54":[14,0,6,0,8,68,1],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html#a0a813e5afe52be89025bd787ceb32f54":[15,0,4,0,6,64,1],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html#a19fb67be7bc6aa858ee34277782a2209":[14,0,6,0,8,68,4],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html#a19fb67be7bc6aa858ee34277782a2209":[15,0,4,0,6,64,4],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html#a4612d9059153f35d60fd2fd5f5ab920a":[14,0,6,0,8,68,6],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html#a4612d9059153f35d60fd2fd5f5ab920a":[15,0,4,0,6,64,6],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html#a4841a1b8e720dbdc8e12c096059975cd":[14,0,6,0,8,68,0],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html#a4841a1b8e720dbdc8e12c096059975cd":[15,0,4,0,6,64,0],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html#a61a9dd849e7ddc208d2baee20c91576f":[14,0,6,0,8,68,8],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html#a61a9dd849e7ddc208d2baee20c91576f":[15,0,4,0,6,64,8],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html#a72bac11fbbcf9d24c41640d0df8c4010":[14,0,6,0,8,68,11],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html#a72bac11fbbcf9d24c41640d0df8c4010":[15,0,4,0,6,64,11],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html#a901a6f116560fc3165cf6d5d66223e03":[14,0,6,0,8,68,5],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html#a901a6f116560fc3165cf6d5d66223e03":[15,0,4,0,6,64,5],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html#ab24b178d6f8fa6440aee947fa4d86ff0":[14,0,6,0,8,68,2],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html#ab24b178d6f8fa6440aee947fa4d86ff0":[15,0,4,0,6,64,2],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html#abe4365568f76f8f85a0eaff8f84f9f06":[14,0,6,0,8,68,10],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html#abe4365568f76f8f85a0eaff8f84f9f06":[15,0,4,0,6,64,10],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html#ace14137a24a932554c792b092bc49f21":[14,0,6,0,8,68,9],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html#ace14137a24a932554c792b092bc49f21":[15,0,4,0,6,64,9],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html#af07a8c75c48174ee79d06fbfe43dd821":[14,0,6,0,8,68,3],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html#af07a8c75c48174ee79d06fbfe43dd821":[15,0,4,0,6,64,3],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html#af7f7cd30525c7cbc594ec0fd2859f5eb":[14,0,6,0,8,68,7],
+"classopenvdb_1_1v12__1_1_1tools_1_1GridSampler_3_01tree_1_1ValueAccessor_3_01TreeT_01_4_00_01SamplerType_01_4.html#af7f7cd30525c7cbc594ec0fd2859f5eb":[15,0,4,0,6,64,7],
 "classopenvdb_1_1v12__1_1_1tools_1_1GridTransformer.html":[14,0,6,0,8,69],
 "classopenvdb_1_1v12__1_1_1tools_1_1GridTransformer.html":[15,0,4,0,6,65],
 "classopenvdb_1_1v12__1_1_1tools_1_1GridTransformer.html#a001a4ff38ee1aa12eab7b329c5f2e115":[14,0,6,0,8,69,17],
@@ -199,55 +249,5 @@ var NAVTREEINDEX52 =
 "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html#ac39f5f86ebd5df29525fec79bdff9f48":[14,0,6,0,8,76,37],
 "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html#ac39f5f86ebd5df29525fec79bdff9f48":[15,0,4,0,6,72,37],
 "classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html#ac47a81c9220d4b14a642caa3b9658612":[14,0,6,0,8,76,8],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html#ac47a81c9220d4b14a642caa3b9658612":[15,0,4,0,6,72,8],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html#ac588142e0d5b33cb94e92dd65e50e927":[14,0,6,0,8,76,46],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html#ac588142e0d5b33cb94e92dd65e50e927":[15,0,4,0,6,72,46],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html#ad2163a3e255b9662a8581cafd9f36ce0":[14,0,6,0,8,76,30],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html#ad2163a3e255b9662a8581cafd9f36ce0":[15,0,4,0,6,72,30],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html#ad27daf87efe47196bc6d2f4df72b8f09":[14,0,6,0,8,76,15],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html#ad27daf87efe47196bc6d2f4df72b8f09":[15,0,4,0,6,72,15],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html#ad78968466f5db80a681505f47ee9b865":[14,0,6,0,8,76,6],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html#ad78968466f5db80a681505f47ee9b865":[15,0,4,0,6,72,6],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html#ae21cb590f50ae47cc5a90bdcb48ccb4b":[14,0,6,0,8,76,28],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html#ae21cb590f50ae47cc5a90bdcb48ccb4b":[15,0,4,0,6,72,28],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html#ae3ac78a3ca1e40637927f339351785cb":[14,0,6,0,8,76,12],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html#ae3ac78a3ca1e40637927f339351785cb":[15,0,4,0,6,72,12],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html#ae74f3c892e518f23d7b874233aa1d86b":[14,0,6,0,8,76,13],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html#ae74f3c892e518f23d7b874233aa1d86b":[15,0,4,0,6,72,13],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html#ae8a054cd2604d15775d1471dd88c2bd6":[14,0,6,0,8,76,1],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html#ae8a054cd2604d15775d1471dd88c2bd6":[15,0,4,0,6,72,1],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html#ae9d62b96d5f8ffc6005fa785733919a6":[14,0,6,0,8,76,3],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html#ae9d62b96d5f8ffc6005fa785733919a6":[15,0,4,0,6,72,3],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html#aee146ef5a7446bd48d820520e556c29d":[14,0,6,0,8,76,22],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html#aee146ef5a7446bd48d820520e556c29d":[15,0,4,0,6,72,22],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html#af613bc7d3737c75db5f01a663a149614":[14,0,6,0,8,76,48],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html#af613bc7d3737c75db5f01a663a149614":[15,0,4,0,6,72,48],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFracture.html":[14,0,6,0,8,77],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFracture.html":[15,0,4,0,6,73],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFracture.html#a1121703dd4585c68f0940065b080d636":[14,0,6,0,8,77,7],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFracture.html#a1121703dd4585c68f0940065b080d636":[15,0,4,0,6,73,7],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFracture.html#a4613728882f107140f1de31023491559":[14,0,6,0,8,77,4],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFracture.html#a4613728882f107140f1de31023491559":[15,0,4,0,6,73,4],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFracture.html#a4ef2833d4d6753549a41a8ab1a47599a":[14,0,6,0,8,77,0],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFracture.html#a4ef2833d4d6753549a41a8ab1a47599a":[15,0,4,0,6,73,0],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFracture.html#a5bed47f213d43c60b54b5d1044f9973d":[14,0,6,0,8,77,2],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFracture.html#a5bed47f213d43c60b54b5d1044f9973d":[15,0,4,0,6,73,2],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFracture.html#ab25ffd950a04e0339d02195d7a84d063":[14,0,6,0,8,77,1],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFracture.html#ab25ffd950a04e0339d02195d7a84d063":[15,0,4,0,6,73,1],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFracture.html#ac8bb3912a3ce86b15842e79d0b421204":[14,0,6,0,8,77,5],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFracture.html#ac8bb3912a3ce86b15842e79d0b421204":[15,0,4,0,6,73,5],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFracture.html#ad4263e4e5dfaadc187e2435e50a67ae7":[14,0,6,0,8,77,3],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFracture.html#ad4263e4e5dfaadc187e2435e50a67ae7":[15,0,4,0,6,73,3],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFracture.html#adf86a35b4c494e2042b1af66c9602c2f":[14,0,6,0,8,77,6],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFracture.html#adf86a35b4c494e2042b1af66c9602c2f":[15,0,4,0,6,73,6],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetMeasure.html":[14,0,6,0,8,78],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetMeasure.html":[15,0,4,0,6,74],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetMeasure.html#a046f96ad983b7b567d07b19044d601b3":[14,0,6,0,8,78,10],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetMeasure.html#a046f96ad983b7b567d07b19044d601b3":[15,0,4,0,6,74,10],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetMeasure.html#a06a49e6e6ac83be87107b22fb4b13576":[14,0,6,0,8,78,7],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetMeasure.html#a06a49e6e6ac83be87107b22fb4b13576":[15,0,4,0,6,74,7],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetMeasure.html#a138ed9db6b6c3280d2df1d2ddeb99f6a":[14,0,6,0,8,78,9],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetMeasure.html#a138ed9db6b6c3280d2df1d2ddeb99f6a":[15,0,4,0,6,74,9],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetMeasure.html#a155052b533640590ff95924125ce5ad8":[14,0,6,0,8,78,5],
-"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetMeasure.html#a155052b533640590ff95924125ce5ad8":[15,0,4,0,6,74,5]
+"classopenvdb_1_1v12__1_1_1tools_1_1LevelSetFilter.html#ac47a81c9220d4b14a642caa3b9658612":[15,0,4,0,6,72,8]
 };
