@@ -1,5 +1,62 @@
 var NAVTREEINDEX84 =
 {
+"namespaceopenvdb_1_1v12__1_1_1tools.html#afb69abc32d73ce0e3cd67b569bed65b8":[14,0,6,0,8,302],
+"namespaceopenvdb_1_1v12__1_1_1tools.html#afbad51b90ae8354757fa735b4d2058b0":[14,0,6,0,8,162],
+"namespaceopenvdb_1_1v12__1_1_1tools.html#aff2004f746efe615a376354f56ae3c6e":[14,0,6,0,8,256],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1Scheme.html":[14,0,6,0,8,8],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1Scheme.html#a28fd66b0310514194a2fb1d2473e3e29":[14,0,6,0,8,8,0],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1Scheme.html#a28fd66b0310514194a2fb1d2473e3e29a0ad105830a21e547b8f07c8d466b77bf":[14,0,6,0,8,8,0,2],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1Scheme.html#a28fd66b0310514194a2fb1d2473e3e29a44cabaec5bbbef7d3e4b7e9a259283f1":[14,0,6,0,8,8,0,1],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1Scheme.html#a28fd66b0310514194a2fb1d2473e3e29a8190f53535f0dc8d9246fdf493756e93":[14,0,6,0,8,8,0,0],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1Scheme.html#a4010e0b09fbf6a975c479833d3001f42":[14,0,6,0,8,8,1],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1Scheme.html#a4010e0b09fbf6a975c479833d3001f42a3bc56824c91d97fcda36dc99687bb236":[14,0,6,0,8,8,1,1],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1Scheme.html#a4010e0b09fbf6a975c479833d3001f42a5df275d4d2ef6e60437567adc263d488":[14,0,6,0,8,8,1,3],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1Scheme.html#a4010e0b09fbf6a975c479833d3001f42a68cf729acfb0cf4857abec621022e0df":[14,0,6,0,8,8,1,0],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1Scheme.html#a4010e0b09fbf6a975c479833d3001f42a9775c41ec65add712b9d4ada46e38672":[14,0,6,0,8,8,1,2],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1Scheme.html#a4010e0b09fbf6a975c479833d3001f42a9c4ceb72dffdf771c0a249aa8d03e769":[14,0,6,0,8,8,1,4],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1Scheme.html#a4010e0b09fbf6a975c479833d3001f42abe1f8538e8f5da855c0ec4c01b584099":[14,0,6,0,8,8,1,5],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1composite.html":[14,0,6,0,8,0],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1composite.html#a0270398d6d5406bfa43d844c342ebe5f":[14,0,6,0,8,0,0],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1composite.html#a4f31bc8f32de5f0afa35e0588a6c5907":[14,0,6,0,8,0,3],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1composite.html#a6d03d215cbfd2a472d36e7b5cabc0c34":[14,0,6,0,8,0,4],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1composite.html#a85157a8c619fa7fd8873039785a8e9c7":[14,0,6,0,8,0,6],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1composite.html#a94403d4d334f702a068b75842bdd8cf5":[14,0,6,0,8,0,1],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1composite.html#ac3d1a5421a7e04d9eaca81d3e0b83407":[14,0,6,0,8,0,2],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1composite.html#ad715de018c1beeec76eec91e8d4828c0":[14,0,6,0,8,0,5],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1ds.html":[14,0,6,0,8,1],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1gridop.html":[14,0,6,0,8,2],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1local__util.html":[14,0,6,0,8,3],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1local__util.html#a057ba643efc5c61f88797c21c7e753fd":[14,0,6,0,8,3,1],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1local__util.html#a4c7613d6a92b35a34aa4e1444551bd39":[14,0,6,0,8,3,0],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1local__util.html#a78af4a2013c67a5e90c9f15cc8a808b2":[14,0,6,0,8,3,3],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1local__util.html#ade4d02464f1de16bcb3f8c78b8a528d7":[14,0,6,0,8,3,2],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1lstrack.html":[14,0,6,0,8,4],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1lstrack.html#a0cd3ac7af16f5e4848317aea237d1bac":[14,0,6,0,8,4,0],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1lstrack.html#a0cd3ac7af16f5e4848317aea237d1baca1b3389cb8203183e22c1495956caff4c":[14,0,6,0,8,4,0,1],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1lstrack.html#a0cd3ac7af16f5e4848317aea237d1baca34bdbffdb1c0e1b603f58fc0d49548b6":[14,0,6,0,8,4,0,3],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1lstrack.html#a0cd3ac7af16f5e4848317aea237d1baca35c3ace1970663a16e5c65baa5941b13":[14,0,6,0,8,4,0,0],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1lstrack.html#a0cd3ac7af16f5e4848317aea237d1bacad0278fb1f054fdae4a877a6b5596d254":[14,0,6,0,8,4,0,2],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1lvlset.html":[14,0,6,0,8,5],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1morphology.html":[14,0,6,0,8,6],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1morphology.html#a162b74cc60225f930ed94e731bcbc922":[14,0,6,0,8,6,2],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1morphology.html#a2138f4a1117354669b1c0527c0f3301e":[14,0,6,0,8,6,1],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html":[14,0,6,0,8,7],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#a11228470b0c119b061330893dcf4d84a":[14,0,6,0,8,7,5],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#a160805a9c45ca3b4150ff5b29da0d1aa":[14,0,6,0,8,7,11],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#a21ab8bffe12c0fdd360cc0fdff53f042":[14,0,6,0,8,7,10],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#a28bc96576c35b652d14262997693ef21":[14,0,6,0,8,7,8],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#a54eb0709abc6cd6d64f8d9685297d9d3":[14,0,6,0,8,7,4],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#a6610683e8f33cef4b298fd92d1e7306f":[14,0,6,0,8,7,2],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#a84c81c332ed27260f4cefebebe118786":[14,0,6,0,8,7,3],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#aa0f700b7e93a8fc04d49928e5350b488":[14,0,6,0,8,7,1],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#aa31211523f1978176daa0219796b87ec":[14,0,6,0,8,7,13],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#aaafc8a2a26f1f3f386afd16268b8c19b":[14,0,6,0,8,7,7],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#ad247afd9be5bc45c0ef563dfdcf9f521":[14,0,6,0,8,7,6],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#ae79d948d2102c9bb9a687c8652b6086d":[14,0,6,0,8,7,9],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1poisson.html#af53fd5faf087f9dc41fac411fb256ad4":[14,0,6,0,8,7,12],
+"namespaceopenvdb_1_1v12__1_1_1tools_1_1valxform.html":[14,0,6,0,8,9],
+"namespaceopenvdb_1_1v12__1_1_1tree.html":[14,0,6,0,9],
+"namespaceopenvdb_1_1v12__1_1_1tree.html#a09d15a8ce9e84448003ae4bb40326488":[14,0,6,0,9,86],
 "namespaceopenvdb_1_1v12__1_1_1tree.html#a2be6027a90f96de5f0afc733ef61967b":[14,0,6,0,9,91],
 "namespaceopenvdb_1_1v12__1_1_1tree.html#a592c66f93fb0e930ce01a393884f35d6":[14,0,6,0,9,89],
 "namespaceopenvdb_1_1v12__1_1_1tree.html#a682224f88f42583ec31fc43552b962b8":[14,0,6,0,9,90],
@@ -138,21 +195,21 @@ var NAVTREEINDEX84 =
 "nanovdb_2nanovdb_2NodeManager_8h_source.html":[16,0,1,7],
 "nanovdb_2nanovdb_2util_2CpuTimer_8h.html":[16,0,1,2,0],
 "nanovdb_2nanovdb_2util_2CpuTimer_8h_source.html":[16,0,1,2,0],
-"nanovdb_2nanovdb_2util_2NodeManager_8h.html":[16,0,1,2,13],
-"nanovdb_2nanovdb_2util_2NodeManager_8h_source.html":[16,0,1,2,13],
-"nanovdb_2nanovdb_2util_2Ray_8h.html":[16,0,1,2,18],
-"nanovdb_2nanovdb_2util_2Ray_8h_source.html":[16,0,1,2,18],
-"nanovdb_2nanovdb_2util_2Stencils_8h.html":[16,0,1,2,21],
-"nanovdb_2nanovdb_2util_2Stencils_8h_source.html":[16,0,1,2,21],
-"nanovdb_2nanovdb_2util_2Util_8h.html":[16,0,1,2,23],
-"nanovdb_2nanovdb_2util_2Util_8h.html#a2bedaa6389282b408e38375ddc049d4a":[16,0,1,2,23,29],
-"nanovdb_2nanovdb_2util_2Util_8h.html#a551e5ea2539324048f4b47c00ab67d55":[16,0,1,2,23,27],
-"nanovdb_2nanovdb_2util_2Util_8h.html#a6206280c40895ecce8b389824bf05ecd":[16,0,1,2,23,28],
-"nanovdb_2nanovdb_2util_2Util_8h.html#a75e2d5456e52f5c9703fc88479472e55":[16,0,1,2,23,25],
-"nanovdb_2nanovdb_2util_2Util_8h.html#a803050db3c78e0db3ea59a0c35499622":[16,0,1,2,23,26],
-"nanovdb_2nanovdb_2util_2Util_8h.html#ad54e07d96efd9a36dfca1a9f27776d62":[16,0,1,2,23,24],
-"nanovdb_2nanovdb_2util_2Util_8h.html#ae38ae5d91a2537aea03144f126048b3d":[16,0,1,2,23,30],
-"nanovdb_2nanovdb_2util_2Util_8h_source.html":[16,0,1,2,23],
+"nanovdb_2nanovdb_2util_2NodeManager_8h.html":[16,0,1,2,14],
+"nanovdb_2nanovdb_2util_2NodeManager_8h_source.html":[16,0,1,2,14],
+"nanovdb_2nanovdb_2util_2Ray_8h.html":[16,0,1,2,19],
+"nanovdb_2nanovdb_2util_2Ray_8h_source.html":[16,0,1,2,19],
+"nanovdb_2nanovdb_2util_2Stencils_8h.html":[16,0,1,2,22],
+"nanovdb_2nanovdb_2util_2Stencils_8h_source.html":[16,0,1,2,22],
+"nanovdb_2nanovdb_2util_2Util_8h.html":[16,0,1,2,24],
+"nanovdb_2nanovdb_2util_2Util_8h.html#a2bedaa6389282b408e38375ddc049d4a":[16,0,1,2,24,29],
+"nanovdb_2nanovdb_2util_2Util_8h.html#a551e5ea2539324048f4b47c00ab67d55":[16,0,1,2,24,27],
+"nanovdb_2nanovdb_2util_2Util_8h.html#a6206280c40895ecce8b389824bf05ecd":[16,0,1,2,24,28],
+"nanovdb_2nanovdb_2util_2Util_8h.html#a75e2d5456e52f5c9703fc88479472e55":[16,0,1,2,24,25],
+"nanovdb_2nanovdb_2util_2Util_8h.html#a803050db3c78e0db3ea59a0c35499622":[16,0,1,2,24,26],
+"nanovdb_2nanovdb_2util_2Util_8h.html#ad54e07d96efd9a36dfca1a9f27776d62":[16,0,1,2,24,24],
+"nanovdb_2nanovdb_2util_2Util_8h.html#ae38ae5d91a2537aea03144f126048b3d":[16,0,1,2,24,30],
+"nanovdb_2nanovdb_2util_2Util_8h_source.html":[16,0,1,2,24],
 "openvdb_2Exceptions_8h.html":[16,0,2,6],
 "openvdb_2Exceptions_8h.html#a3eec2ef3138c64fc5844490187c1b8d1":[16,0,2,6,12],
 "openvdb_2Exceptions_8h.html#a82231e85176ee365b2fe7ec5dae79830":[16,0,2,6,11],
@@ -192,62 +249,5 @@ var NAVTREEINDEX84 =
 "openvdbax.html#axoverview":[9,0],
 "openvdbax.html#docs":[9,0,0],
 "overview.html":[3],
-"overview.html#Contents":[3,0],
-"overview.html#secGrid":[3,5],
-"overview.html#secIterator":[3,7],
-"overview.html#secOverview":[3,1],
-"overview.html#secSpaceAndTrans":[3,4],
-"overview.html#secSparsity":[3,3],
-"overview.html#secToolUtils":[3,6],
-"overview.html#secTree":[3,2],
-"overview.html#subsecInactive":[3,3,1],
-"overview.html#subsecNodeIter":[3,7,1],
-"overview.html#subsecTrans":[3,4,2],
-"overview.html#subsecTraversal":[3,7,3],
-"overview.html#subsecTreeConfig":[3,2,0],
-"overview.html#subsecTreeIter":[3,7,0],
-"overview.html#subsecValueAccessor":[3,7,2],
-"overview.html#subsecValues":[3,3,0],
-"overview.html#subsecVoxSpace":[3,4,0],
-"overview.html#subsecWorSpace":[3,4,1],
-"pages.html":[],
-"pnanovdb__validate__strides_8h.html":[16,0,1,1,0],
-"pnanovdb__validate__strides_8h.html#a5ae96574b59f94b1ba8a95b7fb6f968c":[16,0,1,1,0,2],
-"pnanovdb__validate__strides_8h.html#a72dd2ef42b0df1c3d9dfb69fb9f0bb68":[16,0,1,1,0,1],
-"pnanovdb__validate__strides_8h.html#a955497afb4d8c4f347d53b859fc9f310":[16,0,1,1,0,0],
-"pnanovdb__validate__strides_8h.html#a9dc8f7a00235750a6b3674bbdd025501":[16,0,1,1,0,3],
-"pnanovdb__validate__strides_8h.html#ad462c36333078816f0ba72b089f8f2db":[16,0,1,1,0,4],
-"pnanovdb__validate__strides_8h_source.html":[16,0,1,1,0],
-"points.html":[7],
-"points.html":[0,0],
-"points.html#secPtActiveValues":[7,6,1],
-"points.html#secPtActiveValues":[0,0,6,1],
-"points.html#secPtAttributeHandle":[7,4,1],
-"points.html#secPtAttributeHandle":[0,0,4,1],
-"points.html#secPtAttributePerformance":[7,4,2],
-"points.html#secPtAttributePerformance":[0,0,4,2],
-"points.html#secPtAttributeSet":[7,4,3],
-"points.html#secPtAttributeSet":[0,0,4,3],
-"points.html#secPtAttributes":[7,4],
-"points.html#secPtAttributes":[0,0,4],
-"points.html#secPtBackground":[7,6,0],
-"points.html#secPtBackground":[0,0,6,0],
-"points.html#secPtCompression":[7,2],
-"points.html#secPtCompression":[0,0,2],
-"points.html#secPtContents":[7,0],
-"points.html#secPtContents":[0,0,0],
-"points.html#secPtIndexFilters":[7,6,3],
-"points.html#secPtIndexFilters":[0,0,6,3],
-"points.html#secPtIndexIterators":[7,6,2],
-"points.html#secPtIndexIterators":[0,0,6,2],
-"points.html#secPtLocality":[7,3],
-"points.html#secPtLocality":[0,0,3],
-"points.html#secPtOverview":[7,1],
-"points.html#secPtOverview":[0,0,1],
-"points.html#secPtPointDataTree":[7,5,1],
-"points.html#secPtPointDataTree":[0,0,5,1],
-"points.html#secPtPointIndexTree":[7,5,0],
-"points.html#secPtPointIndexTree":[0,0,5,0],
-"points.html#secPtPointTree":[7,5],
-"points.html#secPtPointTree":[0,0,5]
+"overview.html#Contents":[3,0]
 };
